Auth0ChangePasswordRequest class

Represents a request to change a user's password in Auth0.

This class contains the necessary information required by Auth0's change password endpoint, including the client ID, user email, and connection type.

Constructors

Auth0ChangePasswordRequest({required String clientId, required String email, required String connection})
Creates an Auth0ChangePasswordRequest instance.

Properties

clientId String
The client ID of the Auth0 application.
final
connection String
The Auth0 connection type (e.g., 'Username-Password-Authentication').
final
email String
The email address of the user requesting a password change.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this request object to a JSON map suitable for sending to Auth0.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited