Auth0AuthenticateUser class
Handles user authentication with Auth0.
This class facilitates the authentication of a user by sending a request to the
Auth0 authentication endpoint (/oauth/token) with the provided credentials and request parameters.
It processes the response and returns the result as an Auth0AuthenticateUserResponse object.
Example usage:
final authService = Auth0AuthenticateUser(domain: 'your-auth0-domain');
final request = Auth0AuthenticateUserRequest(clientId: 'your-client-id', clientSecret: 'your-client-secret');
try {
final response = await authService.authenticate(request: request);
print(response);
} catch (e) {
print('Authentication failed: $e');
}
Constructors
- Auth0AuthenticateUser({required String domain})
- Constructs an instance of Auth0AuthenticateUser.
Properties
Methods
-
authenticate(
{required Auth0AuthenticateUserRequest request}) → Future< Auth0AuthenticateUserResponse> -
Authenticates a user by sending a request to the Auth0
/oauth/tokenendpoint. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited